California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 063- FIREARMS. AMMUNITION SALES. INTIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1382067 | COALITION FOR CIVIL LIBERTIES - NO ON 63, A PROJECT OF CALIFORNIA RIFLE & PISTOL ASSOCIATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1387279 | VETO GUNMAGEDDON, CITIZENS WHO ARE OPPOSED TO PROPOSITION 63, ASSEMBLY BILLS 1135, 1511, 1695, 857 AND SENATE BILLS 880, 1235 AND 1446 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1380675 | NEWSOM BALLOT MEASURE COMMITTEE; SAFETY FOR ALL, YES ON PROP. 63, | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1380746 | STOP PROP 63, A GRASSROOTS, COMMON-SENSE EFFORT FOR RATIONAL POLICY SPONSORED BY FIREARMS POLICY COALITION | OPPOSE